@@ -12,9 +12,8 @@ extract_fasttree_constraints = function(tree){
 												Nedges		= nrow(tree$edge),
 												tree_edge	= as.vector(t(tree$edge))-1);	# flatten in row-major format and make indices 0-based
 	Nconstraints = results$Nconstraints
-	constraints	 = matrix(results$constraints, ncol=Nconstraints, byrow=TRUE)
-	constraint2node = rep(0,times=Nconstraints); constraint2node[results$node2constraint+1] = c(1:Nnodes);
+	constraints	 = matrix(results$constraints, ncol=Nconstraints, byrow=TRUE) # unflatten constraints into a 2D matrix
 	return(list(Nconstraints	= Nconstraints,
 				constraints 	= constraints,
-				constraint2node	= constraint2node));
+				constraint2node	= results$constraint2node+1));
 }
\ No newline at end of file
