@@ -87,7 +87,7 @@ fit_hbd_pdr_parametric = function(	tree,
 	fitted_params	= sanitized_params$fitted_params
 	fixed_params	= sanitized_params$fixed_params
 	
-	if((NFP>0) && model_fixed) return(list(success=FALSE, error="At least one model parameter is fitted, however all model aspects (lambda, mu, rho, kappa etc) are fixed"))
+	if((NFP>0) && model_fixed) return(list(success=FALSE, error="At least one model parameter is fitted, however all model aspects (PDR and rholambda0) are fixed"))
 	
 	# check if functionals are valid at least on the initial guess
 	PDR_guess = PDR(age_grid+age0,param_guess)
